FakeClock class final

Mutable deterministic clock for tests.

Implemented types

Constructors

FakeClock(DateTime initialUtc)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

advance(Duration duration) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
nowUtc() DateTime
override
setUtc(DateTime utc) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited