InMemoryLogSink class final

Test sink that captures records in memory.

Implemented types

Constructors

InMemoryLogSink({void onEnqueue(LogRecord record)?, Future<void> onFlush()?, Future<void> onDispose()?})

Properties

disposed bool
getter/setter pair
flushCount int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
initialized bool
getter/setter pair
onDispose Future<void> Function()?
final
onEnqueue → void Function(LogRecord record)?
final
onFlush Future<void> Function()?
final
records List<LogRecord>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
override
enqueue(LogRecord record) → void
override
flush() Future<void>
override
init() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited